summaryrefslogtreecommitdiff
path: root/test/unit/context/cdhashmap_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/context/cdhashmap_black.cpp')
-rw-r--r--test/unit/context/cdhashmap_black.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/unit/context/cdhashmap_black.cpp b/test/unit/context/cdhashmap_black.cpp
index a5788a585..51d76070a 100644
--- a/test/unit/context/cdhashmap_black.cpp
+++ b/test/unit/context/cdhashmap_black.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::context::CDMap<>.
**
** Black box testing of CVC4::context::CDMap<>.
**/
#include <map>
@@ -21,11 +21,11 @@
#include "context/cdlist.h"
#include "test_context.h"
-namespace CVC4 {
+namespace CVC5 {
namespace test {
-using CVC4::context::CDHashMap;
-using CVC4::context::Context;
+using CVC5::context::CDHashMap;
+using CVC5::context::Context;
class TestContextBlackCDHashMap : public TestContext
{
@@ -203,4 +203,4 @@ TEST_F(TestContextBlackCDHashMap, insert_at_context_level_zero)
ASSERT_TRUE(elements_are(map, {{3, 4}, {23, 317}}));
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::context::CDMap<>.
+ ** \brief Black box testing of CVC5::context::CDMap<>.
**
@@ -9,9 +9,9 @@
**
- ** Black box testing of CVC4::context::CDMap<>.
+ ** Black box testing of CVC5::context::CDMap<>.
**/
#include <map>